<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Zapri (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Pomanjšaj</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Razširi</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Odstrani opozorilo</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln besede</numerusform>
            <numerusform>%Ln besed</numerusform>
            <numerusform>%Ln besed</numerusform>
            <numerusform>%Ln besed</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minut</numerusform>
            <numerusform>%Ln minute</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% od %Ln minute</numerusform>
            <numerusform>%L1% od %Ln minut</numerusform>
            <numerusform>%L1% od %Ln minut</numerusform>
            <numerusform>%L1% od %Ln minut</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% od %Ln besed</numerusform>
            <numerusform>%L1% od %Ln besed</numerusform>
            <numerusform>%L1% od %Ln besed</numerusform>
            <numerusform>%L1% od %Ln besed</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Dnevni napredek</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Najdaljši odstavek</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Trenutni odstavek</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dan</numerusform>
            <numerusform>%n dni</numerusform>
            <numerusform>%n dni</numerusform>
            <numerusform>%n dni</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% dnevnega cilja</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Nastavi jezik</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Neimenovano %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Samo za branje)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Oprostite</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Shranjevanje &apos;%1&apos; ni mogoče.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Shrani datoteko kot</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Prepisovanje &apos;%1&apos; ni bilo mogoče.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Preimenuj datoteko</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Preimenovanje &apos;%1&apos; ni bilo mogoče.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Ponovno naložim?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Ali datoteko &apos;%1&apos; ponovno naložim iz diska?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Vse neshranjene spremembe bodo izgubljene.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ponovno naloži</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Neimenovano %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Shranjevanje kot navadno besedilo bo odstranilo vso oblikovanje. Odstranim oblikovanje?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Datoteka je bila spremenjena</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Datoteko &apos;%1&apos; je spremenil drug program.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Ali naj ponovno naložim datoteko?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ponovno naloži</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoriraj</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Datoteka je bila izbrisana</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Datoteko %1 je izbrisal drug program.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Ali želite shraniti ali zapreti datoteko?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arhiva ni bilo mogoče odpreti.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Išči:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Zamenjaj z:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ne upoštevaj velikosti začetnic</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Samo cele besede</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Regularni izrazi</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Išči gor</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Išči dol</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Išči(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>Zamenjaj(&amp;R)</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Z&amp;amenjej vse</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Išči</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zamenjaj</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Zamenjaj %n pojavitev?</numerusform>
            <numerusform>Zamenjaj %n pojavitev?</numerusform>
            <numerusform>Zamenjaj %n pojavitev?</numerusform>
            <numerusform>Zamenjaj %n pojavitev?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Oprostite</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Izraz ni bil najden.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument besedilo</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Enostavno besedilo</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Vse datoteke</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Vse podprte datoteke</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Preveri pravopis...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Ni predlogov)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Odpri sliko</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Slike(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Izberi jezik programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opomba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Prosimo, ponovno zaženite program, da se uveljavi spremembe jezika.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arhiva ni bilo mogoče odpreti</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Orodna vrstica</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Preverjanje pravopisa</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Izberi slovar</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Oprostite</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Arhiv ani bilo mogoče odpreti.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Arhiv ne vsebuje uporabnega slovarja.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Bližnjice</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Ena ali več bližnjic je v sporu. Ali naj nadaljujem?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Slovar &quot;%1&quot; že obstaja. Ali ga naj zamenjam?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Dnevni cilj</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brez</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minut:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Besed:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Urejanje</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Vedno centriraj navpično</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Kurzur z vstavljanje blokov</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Mehčanje pisav</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Zvok pisalnega stroja</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Pametni navedki:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvojno</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enojno</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scene</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Delitelj:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Shranjevanje</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Zapomni si položaj utripača</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Štetje besed</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Štetje strani</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Štetje odstavkov</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Štetje znakov</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Znaki:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Odstavki:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritem za štetje besed</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Ponastavim dnevni napredek za danes na nič?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Zapiši vrstni red bytov kot tekst.</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Privzeti format:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Ponastavi za danes</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Zgodovina</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Beleži zgodovino</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Pokaži trake</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimalni napredek za etape:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Zaznaj meje besed</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Deli število znakov s sešt</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Štej vsak znak kot besedo</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algortem za štetje strani</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Slog</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Samo ikone</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Samo besedilo</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Besedilo ob ikonah</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Besedilo pod ikonami</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Položaj besedila:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Aktivnosti</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Premik gor</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Premik dol</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Dodaj delilnik</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Ukaz</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Bližnjica</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aktivnost</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Preverjaj pravopis med tipkanjem</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Zanemari besede v VELIKIH črkah</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Zanemari besede s številkami</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jezik</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Osebni slovar</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Odstranim trenutni slovar?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Uporabniški vmesnik</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Vedno prikaži drsnik</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Vedno prikaži zgornjo vrstico</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Vedno prikaži vrstico na dnu</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Ni podprta RTF datoteka.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Nepričakovano smo naleteli na konec datoteke.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Dol</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Premakni scene gor</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Gor</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Zamenjaj seznam scen</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Pokaže seznam scen (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Skrij seznam scen (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Premakni scene dol</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Spremeni velikost seznama scen</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Upravljaj seje</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;eje</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Preklopi na</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova seja</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Podvoji sejo</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Preimenuj sejo</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Izbrišem trenutno sejo?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Ime seje:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Oprostite</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Izbrano ime seje je že v uporabi.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nova...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>(&amp;M)Upravljaj...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Počisti</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Ponastavi na privzeto</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Bližnjica:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Zamenjava narekovajev...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Prosim počakajte</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Preveri pravopis</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>Dod&amp;aj</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignoriraj</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnoriraj vse</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>(&amp;C)Spremeni</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>(&amp;H)Spremeni vse</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Ni v slovarju:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Spremeni v:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Preverjanje pravopisa...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Prosim počakajte</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Nadaljujem s preverjanjem od začetka datoteke?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Preverjanje pravopisa končano.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Simboli</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Nedavno uporabljeni simboli</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Vsi simboli</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Vstavi</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Bloki</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Skripti</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Neimenovan/o %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Ni slike</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Razporejeno</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrirano</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Raztegnjeno</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Raztegnjeno</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Zumirano</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Prosojnost:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Položaj:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Širina:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Zaokroži ogale ozadja besedila</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Polmer:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Razmaži ozadje besedila</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Senca na ozadju besedila</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Navpični odmik:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Robovi</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Okno:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Stran:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Zamik prve vrstice</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Nad:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Pod:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstrani</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Uredi temo</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Ozadje okna</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Vrsta:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Slika:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>pixlov</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Ozadje besedila</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Besedilo</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Pisava:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Narobe črkovano:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Razmik vrstic</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Enojno</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 vrstice</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvojno</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcionalno</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Višina:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Razmik odstavkov</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Širina tabulatorja:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nova tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Teme</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Privzeto</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Nežna modrina</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Stara šola</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Vesoljske sanje</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Pisalna miza</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Podvoji</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Prilagojeno</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Uvozi</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Izvozi</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Brisanje teme &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Teme (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Uvozi temo</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Izvozi temo</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Grenko nebo</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Začarano</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Vohunske igre</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Spokojnost</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Izbrišem časovnik?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Besed:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Strani:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Odstavkov:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Znakov:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Nastavi zamik</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Nastavi čas</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Zamik:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Čas:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Vrsta:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Uredi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Ni dejavnih časovnikov</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Časovniki</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Zadnje</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vprašanje</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Prekliči urejanje časovnikov?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Nalaganje tem</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Nalaganje zvokov</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Neimenovano</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Odpri datoteko</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>O FocusWriterju</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Enostaven celozaslonski urejevalnik besedila</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Objavljeno pod &lt;a href=%1&gt;GPL 3&lt;/a&gt; licenco</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Uporablja ikone iz teme &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Uporaba pod &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licenco</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Znaki: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Strani: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Odstavki: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Besede: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Odpiranje %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Neimenovano %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Seznam vseh dokumentov</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Preklopi na naslednji dokument</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Preklopi na prejšnji dokument</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Preklopi na prvi dokument</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Preklopi na zadnji dokument</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Preklopi na dokument %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Nalaganje nastavitev</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Zasilni spomin ni zapisljiv.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter ni bil pravilno izklopljen.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Obnovi iz začasne kopije?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Nekaterih datotek ni bilo mogoče odpreti.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Nekatere datoteke so odprte le za branje.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; je novejše kot kopija v spominu.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Prepišem novejšo datoteko?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Shranim spremembe?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Shranim spremembe v datoteko &apos;%1&apos; pred zapiranjem?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vaše spremembe bodo izgubljene, če jih ne shranite.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nalaganje zvokov pisalnega stroja ni bilo uspešno.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Odpri...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Ponovno na&amp;loži</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Shrani</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Shr&amp;ani kot...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>P&amp;reimenuj</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Shrani &amp;vse</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Upravjanje seje</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova seja</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Natisni...(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Zapri(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Iz&amp;hod</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Ur&amp;edi</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Razveljavi(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Uveljavi(&amp;R)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Izreži(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Kopiraj(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Prilepi</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Prilepi neoblikovano(&amp;U)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Izberi vse(&amp;A)</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Izberi &amp;sceno</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmat</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>(&amp;B)Krepko</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>(&amp;I) Poševno</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>(&amp;U) Podčrtano</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>(&amp;K)Prečrtano</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>(&amp;E)Nadpisano</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>(&amp;S)Podpisano</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>&amp;Leva poravnava</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Centralna poravnava</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>(&amp;R)Desna poravnava</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>(&amp;J) Obojestranska poravnava</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>(&amp;D)Zmanjšaj razmik</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Povečaj razm&amp;ik</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>(&amp;F)Blok od leve proti desni</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>(&amp;G)Blok od desne proti levi</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Orodja</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Iskanje...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Poišči &amp;naprej</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Poišči na&amp;zaj</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Zam&amp;enjaj...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Pametni navedki</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Posodobi &amp;dokument</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Po&amp;sodobi izbor</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Pravopi&amp;s...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Nastavi jezik(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Časovniki...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Simboli...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Dnevni napredek</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Na&amp;stavitve</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Pokaži orodno vrs&amp;tice</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Pokaži &amp;menijske ikone</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>&amp;Označeno besedilo</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Celoten zaslon</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimziraj</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Teme...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Nastavitve...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Izklopi fokus</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Fokus na eno vrstico</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Fokus na tri vrstice</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>Odstavek</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Fokus na odstavek</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Jezik ap&amp;likacije...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Nekaj datotek je nepodprtih in jih ni bilo mogoče odpreti.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>Izkl&amp;opljeno</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Ena vrstica</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tri vrstice</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O...</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Postavitev st&amp;rani...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Naslov (&amp;H)</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Naslov &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Naslov &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Naslov &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Naslov &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Naslov &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Naslov &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Posodobi pametne oznake dokumenta</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Posodobi pametne oznake izbranega</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
</TS>
